@@ -27,10 +27,10 @@ def _get_path_extensions():
 
 
 EXTENSIONS = _get_path_extensions()
-_CONF_VAR_RE = re.compile(r"\{\w+\}")
+_CONF_VAR_RE = re.compile(r"\{\w+}")
 
 
-class PythonInfo:
+class PythonInfo:  # noqa: PLR0904
     """Contains information for a Python interpreter."""
 
     def __init__(self) -> None:  # noqa: PLR0915
@@ -135,6 +135,7 @@ class PythonInfo:
         self.system_stdlib = self.sysconfig_path("stdlib", confs)
         self.system_stdlib_platform = self.sysconfig_path("platstdlib", confs)
         self.max_size = getattr(sys, "maxsize", getattr(sys, "maxint", None))
+        self._creators = None
 
     @staticmethod
     def _get_tcl_tk_libs():
@@ -310,6 +311,13 @@ class PythonInfo:
             config_var = base
         return pattern.format(**config_var).replace("/", sep)
 
+    def creators(self, refresh=False):  # noqa: FBT002
+        if self._creators is None or refresh is True:
+            from virtualenv.run.plugin.creators import CreatorSelector  # noqa: PLC0415
+
+            self._creators = CreatorSelector.for_interpreter(self)
+        return self._creators
+
     @property
     def system_include(self):
         path = self.sysconfig_path(
@@ -378,14 +386,14 @@ class PythonInfo:
         )
 
     @classmethod
-    def clear_cache(cls, app_data, cache=None):
+    def clear_cache(cls, app_data):
         # this method is not used by itself, so here and called functions can import stuff locally
         from virtualenv.discovery.cached_py_info import clear  # noqa: PLC0415
 
-        clear(app_data, cache)
+        clear(app_data)
         cls._cache_exe_discovery.clear()
 
-    def satisfies(self, spec, impl_must_match):  # noqa: C901, PLR0911
+    def satisfies(self, spec, impl_must_match):  # noqa: C901, PLR0911, PLR0912
         """Check if a given specification can be satisfied by the this python interpreter instance."""
         if spec.path:
             if self.executable == os.path.abspath(spec.path):
@@ -414,6 +422,20 @@ class PythonInfo:
         if spec.free_threaded is not None and spec.free_threaded != self.free_threaded:
             return False
 
+        if spec.version_specifier is not None:
+            version_info = self.version_info
+            release = f"{version_info.major}.{version_info.minor}.{version_info.micro}"
+            if version_info.releaselevel != "final":
+                suffix = {
+                    "alpha": "a",
+                    "beta": "b",
+                    "candidate": "rc",
+                }.get(version_info.releaselevel)
+                if suffix is not None:
+                    release = f"{release}{suffix}{version_info.serial}"
+            if not spec.version_specifier.contains(release):
+                return False
+
         for our, req in zip(self.version_info[0:3], (spec.major, spec.minor, spec.micro)):
             if req is not None and our is not None and our != req:
                 return False
@@ -423,35 +445,23 @@ class PythonInfo:
     _current = None
 
     @classmethod
-    def current(cls, app_data=None, cache=None):
+    def current(cls, app_data=None):
         """
         This locates the current host interpreter information. This might be different than what we run into in case
         the host python has been upgraded from underneath us.
         """  # noqa: D205
         if cls._current is None:
-            cls._current = cls.from_exe(
-                sys.executable,
-                app_data,
-                raise_on_error=True,
-                resolve_to_host=False,
-                cache=cache,
-            )
+            cls._current = cls.from_exe(sys.executable, app_data, raise_on_error=True, resolve_to_host=False)
         return cls._current
 
     @classmethod
-    def current_system(cls, app_data=None, cache=None) -> PythonInfo:
+    def current_system(cls, app_data=None) -> PythonInfo:
         """
         This locates the current host interpreter information. This might be different than what we run into in case
         the host python has been upgraded from underneath us.
         """  # noqa: D205
         if cls._current_system is None:
-            cls._current_system = cls.from_exe(
-                sys.executable,
-                app_data,
-                raise_on_error=True,
-                resolve_to_host=True,
-                cache=cache,
-            )
+            cls._current_system = cls.from_exe(sys.executable, app_data, raise_on_error=True, resolve_to_host=True)
         return cls._current_system
 
     def _to_json(self):
@@ -459,7 +469,8 @@ class PythonInfo:
         return json.dumps(self._to_dict(), indent=2)
 
     def _to_dict(self):
-        data = {var: getattr(self, var) for var in vars(self)}
+        data = {var: (getattr(self, var) if var != "_creators" else None) for var in vars(self)}
+
         data["version_info"] = data["version_info"]._asdict()  # namedtuple to dictionary
         return data
 
@@ -472,26 +483,17 @@ class PythonInfo:
         ignore_cache=False,  # noqa: FBT002
         resolve_to_host=True,  # noqa: FBT002
         env=None,
-        cache=None,
     ):
         """Given a path to an executable get the python information."""
         # this method is not used by itself, so here and called functions can import stuff locally
-        from virtualenv.discovery.cached_py_info import from_exe as from_exe_cache  # noqa: PLC0415
+        from virtualenv.discovery.cached_py_info import from_exe  # noqa: PLC0415
 
         env = os.environ if env is None else env
-        proposed = from_exe_cache(
-            cls,
-            app_data,
-            exe,
-            env=env,
-            raise_on_error=raise_on_error,
-            ignore_cache=ignore_cache,
-            cache=cache,
-        )
+        proposed = from_exe(cls, app_data, exe, env=env, raise_on_error=raise_on_error, ignore_cache=ignore_cache)
 
         if isinstance(proposed, PythonInfo) and resolve_to_host:
             try:
-                proposed = proposed._resolve_to_system(app_data, proposed, cache=cache)  # noqa: SLF001
+                proposed = proposed._resolve_to_system(app_data, proposed)  # noqa: SLF001
             except Exception as exception:
                 if raise_on_error:
                     raise
@@ -513,7 +515,7 @@ class PythonInfo:
         return result
 
     @classmethod
-    def _resolve_to_system(cls, app_data, target, cache=None):
+    def _resolve_to_system(cls, app_data, target):
         start_executable = target.executable
         prefixes = OrderedDict()
         while target.system_executable is None:
@@ -530,15 +532,15 @@ class PythonInfo:
                 msg = "prefixes are causing a circle {}".format("|".join(prefixes.keys()))
                 raise RuntimeError(msg)
             prefixes[prefix] = target
-            target = target.discover_exe(app_data, prefix=prefix, exact=False, cache=cache)
+            target = target.discover_exe(app_data, prefix=prefix, exact=False)
         if target.executable != target.system_executable:
-            target = cls.from_exe(target.system_executable, app_data, cache=cache)
+            target = cls.from_exe(target.system_executable, app_data)
         target.executable = start_executable
         return target
 
     _cache_exe_discovery = {}  # noqa: RUF012
 
-    def discover_exe(self, app_data, prefix, exact=True, env=None, cache=None):  # noqa: FBT002
+    def discover_exe(self, app_data, prefix, exact=True, env=None):  # noqa: FBT002
         key = prefix, exact
         if key in self._cache_exe_discovery and prefix:
             LOGGER.debug("discover exe from cache %s - exact %s: %r", prefix, exact, self._cache_exe_discovery[key])
@@ -551,7 +553,7 @@ class PythonInfo:
         env = os.environ if env is None else env
         for folder in possible_folders:
             for name in possible_names:
-                info = self._check_exe(app_data, folder, name, exact, discovered, env, cache)
+                info = self._check_exe(app_data, folder, name, exact, discovered, env)
                 if info is not None:
                     self._cache_exe_discovery[key] = info
                     return info
@@ -564,18 +566,11 @@ class PythonInfo:
         msg = "failed to detect {} in {}".format("|".join(possible_names), os.pathsep.join(possible_folders))
         raise RuntimeError(msg)
 
-    def _check_exe(self, app_data, folder, name, exact, discovered, env, cache):  # noqa: PLR0913
+    def _check_exe(self, app_data, folder, name, exact, discovered, env):  # noqa: PLR0913
         exe_path = os.path.join(folder, name)
         if not os.path.exists(exe_path):
             return None
-        info = self.from_exe(
-            exe_path,
-            app_data,
-            resolve_to_host=False,
-            raise_on_error=False,
-            env=env,
-            cache=cache,
-        )
+        info = self.from_exe(exe_path, app_data, resolve_to_host=False, raise_on_error=False, env=env)
         if info is None:  # ignore if for some reason we can't query
             return None
         for item in ["implementation", "architecture", "version_info"]:
@@ -659,8 +654,7 @@ class PythonInfo:
         for base in possible_base:
             lower = base.lower()
             yield lower
-
-            from .info import fs_is_case_sensitive  # noqa: PLC0415
+            from virtualenv.info import fs_is_case_sensitive  # noqa: PLC0415
 
             if fs_is_case_sensitive():
                 if base != lower:
